==> vst3sdk-docs-3.7.14_build_55-1-any.pkg.tar.zst: usr/share/doc/vst3sdk-docs/vstexamples/classSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1ControllerWithUI.js <==
var classSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1ControllerWithUI =
[
    [ "UTF8StringPtr", "classSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1ControllerWithUI.html#af7e79066204c7e0be05f30d63bcafb24", null ],
    [ "IController", "classSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1ControllerWithUI.html#af63358114b145c306987ac513b4e908d", null ],
    [ "IUIDescription", "classSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1ControllerWithUI.html#aa946c9736e3aad934fd2d9b7b916cc43", null ],
    [ "VST3Editor", "classSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1ControllerWithUI.html#ae5ece0a3a8c6e4295d9adedb76d6edd8", null ],
    [ "initialize", "classSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1ControllerWithUI.html#a4dae123b5697706651d9ff20c9614f63", null ],
    [ "terminate", "classSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1ControllerWithUI.html#a272e5d4c8e24f012573f9f5b11f7f569", null ],
    [ "createView", "classSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1ControllerWithUI.html#aa2fea25360b1f4824345acc423b1f8db", null ],
    [ "setState", "classSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1ControllerWithUI.html#a9228db732b48ece8b5b734e69b979d10", null ],
    [ "getState", "classSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1ControllerWithUI.html#aee393393dc4dccf6e0b30a43380859b4", null ],
    [ "beginEdit", "classSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1ControllerWithUI.html#a60aee36a21805e563d61242be6e7d8b0", null ],
    [ "performEdit", "classSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1ControllerWithUI.html#a3310a1682cdcf572f5e22f59869b8e3c", null ],
    [ "endEdit", "classSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1ControllerWithUI.html#a55f180ed79364469774124be9d724160", null ],
    [ "onLiveMIDIControllerInput", "classSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1ControllerWithUI.html#ad8535466d93aa534a40ae1244940cc52", null ],
    [ "createSubController", "classSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1ControllerWithUI.html#ac8f9a7e40bf5981bc73eaf685034b4d4", null ],
    [ "isPrivateParameter", "classSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1ControllerWithUI.html#a8f5398486378a76ec028b304ddb2ee77", null ],
    [ "keyboardRange", "classSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1ControllerWithUI.html#ab86046c9174e294df454f1b7ac321e7e", null ],
    [ "midiLearnParamID", "classSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1ControllerWithUI.html#a8cef184b72b4074c934a5691b745e5df", null ],
    [ "doMIDILearn", "classSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1ControllerWithUI.html#a0d13b05ef372806de086eec80526daae", null ]
];

==> vst3sdk-docs-3.8.0_build_66-1-any.pkg.tar.zst: usr/share/doc/vst3sdk-docs/vstexamples/classSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1ControllerWithUI.js <==
var classSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1ControllerWithUI =
[
    [ "UTF8StringPtr", "classSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1ControllerWithUI.html#af7e79066204c7e0be05f30d63bcafb24", null ],
    [ "IController", "classSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1ControllerWithUI.html#af63358114b145c306987ac513b4e908d", null ],
    [ "IUIDescription", "classSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1ControllerWithUI.html#aa946c9736e3aad934fd2d9b7b916cc43", null ],
    [ "VST3Editor", "classSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1ControllerWithUI.html#ae5ece0a3a8c6e4295d9adedb76d6edd8", null ],
    [ "initialize", "classSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1ControllerWithUI.html#a4dae123b5697706651d9ff20c9614f63", null ],
    [ "terminate", "classSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1ControllerWithUI.html#a272e5d4c8e24f012573f9f5b11f7f569", null ],
    [ "createView", "classSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1ControllerWithUI.html#aa2fea25360b1f4824345acc423b1f8db", null ],
    [ "setState", "classSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1ControllerWithUI.html#a9228db732b48ece8b5b734e69b979d10", null ],
    [ "getState", "classSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1ControllerWithUI.html#aee393393dc4dccf6e0b30a43380859b4", null ],
    [ "beginEdit", "classSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1ControllerWithUI.html#a60aee36a21805e563d61242be6e7d8b0", null ],
    [ "performEdit", "classSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1ControllerWithUI.html#a3310a1682cdcf572f5e22f59869b8e3c", null ],
    [ "endEdit", "classSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1ControllerWithUI.html#a55f180ed79364469774124be9d724160", null ],
    [ "onLiveMIDIControllerInput", "classSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1ControllerWithUI.html#ad8535466d93aa534a40ae1244940cc52", null ],
    [ "onLiveMidi2ControllerInput", "classSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1ControllerWithUI.html#acbb7cb113623a741222a09c2df63517b", null ],
    [ "onLiveMidi1ControllerInput", "classSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1ControllerWithUI.html#ab023303c00dcd1bb6856bf7bf89c01ec", null ],
    [ "createSubController", "classSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1ControllerWithUI.html#ac8f9a7e40bf5981bc73eaf685034b4d4", null ],
    [ "isPrivateParameter", "classSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1ControllerWithUI.html#a8f5398486378a76ec028b304ddb2ee77", null ],
    [ "removeCurrentMidiLearnParamAssignment", "classSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1ControllerWithUI.html#a3e139e7109c8144d9026c62df0f73c0d", null ],
    [ "keyboardRange", "classSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1ControllerWithUI.html#ae5a413751588051fb3326e925c7062f0", null ],
    [ "midiLearnParamID", "classSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1ControllerWithUI.html#a8cef184b72b4074c934a5691b745e5df", null ],
    [ "doMIDILearn", "classSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1ControllerWithUI.html#a0d13b05ef372806de086eec80526daae", null ]
];
